# Flyto2 Core - Source Available License
# Copyright (c) 2025 Flyto2. All Rights Reserved.
#
# This source code is licensed under the Flyto2 Source Available License v1.0.
# Commercial use requires a license. See LICENSE for details.

"""
AST-Based Detectors for flyto-core validation.

Detectors analyze Python source code to find:
- Capabilities from imports and function calls
- Parameter usage vs schema
- Return values vs output_schema
"""

from .capability_detector import (
    CapabilityDetector,
    CapabilityAnalysis,
    detect_capabilities,
    detect_imports,
    analyze_capabilities,
)
from .params_usage_detector import (
    ParamsUsageDetector,
    verify_params_usage,
)
from .return_detector import (
    ReturnValueDetector,
    verify_return_schema,
)

__all__ = [
    "CapabilityDetector",
    "CapabilityAnalysis",
    "detect_capabilities",
    "detect_imports",
    "analyze_capabilities",
    "ParamsUsageDetector",
    "verify_params_usage",
    "ReturnValueDetector",
    "verify_return_schema",
]
