# Flyto2 Core - Source Available License
# Copyright (c) 2025 Flyto2. All Rights Reserved.
#
# This source code is licensed under the Flyto2 Source Available License v1.0.
# Commercial use requires a license. See LICENSE for details.

"""
Core Analysis Package - Stub for OSS version

Full implementation available in Flyto Pro.
"""

from .html_analyzer import HTMLAnalyzer

__all__ = ["HTMLAnalyzer"]
